﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace BackgroundDataTransfer
{
	using System;
	using System.Collections.Generic;
	using System.Linq;

	using Windows.ApplicationModel.Core;
	using Windows.Foundation;
	using Windows.Networking.BackgroundTransfer;
	using Windows.Storage;
	using Windows.UI.Core;

	/// <summary>
	/// An empty page that can be used on its own or navigated to within a Frame.
	/// </summary>
	public sealed partial class MainPage : Page
	{
		private const string FileName = "http://debian.fastweb.it/debian-cd/current/i386/iso-cd/debian-7.4.0-i386-CD-1.iso";
		private readonly CoreDispatcher dispatcher = CoreApplication.MainView.CoreWindow.Dispatcher;
		private BackgroundDownloader downloader;
		private IAsyncOperationWithProgress<DownloadOperation, DownloadOperation> operation;

		public MainPage()
		{
			this.InitializeComponent();
			this.ResumePendingDownloads();
		}

		private async void OnDownload(object sender, RoutedEventArgs e)
		{
			this.downloader = new BackgroundDownloader() { CostPolicy = BackgroundTransferCostPolicy.UnrestrictedOnly };

			//Create destination file
			StorageFile file = await ApplicationData.Current.TemporaryFolder.CreateFileAsync("data.dat", CreationCollisionOption.ReplaceExisting);

			DownloadOperation op = this.downloader.CreateDownload(new Uri(FileName, UriKind.Absolute), file);
			this.operation = op.StartAsync();
			this.operation.Completed += this.OnCompleted;
			this.operation.Progress += this.OnProgress;
		}

		private void OnProgress(IAsyncOperationWithProgress<DownloadOperation, DownloadOperation> asyncinfo, DownloadOperation progressinfo)
		{
			this.dispatcher.RunAsync(
				CoreDispatcherPriority.Normal,
				() =>
				{
					double percent = (double)progressinfo.Progress.BytesReceived / (double)progressinfo.Progress.TotalBytesToReceive;
					InfoTextBlock.Text = string.Format("{0:0.0}%", 100 * percent);
				});

		}

		private void OnCompleted(IAsyncOperationWithProgress<DownloadOperation, DownloadOperation> asyncinfo, AsyncStatus asyncstatus)
		{
			this.dispatcher.RunAsync(
				CoreDispatcherPriority.Normal,
				() =>
				{
					InfoTextBlock.Text = asyncstatus == AsyncStatus.Canceled ? "Canceled" : "Done!";
				});
		}

		private void OnAbort(object sender, RoutedEventArgs e)
		{
			if (this.operation != null) this.operation.Cancel();
		}

		private async void ResumePendingDownloads()
		{
			var pendingOperations = await BackgroundDownloader.GetCurrentDownloadsAsync();
			if (pendingOperations.Any())
			{
				DownloadOperation pendingOperation = pendingOperations.First();
				this.operation = pendingOperation.AttachAsync();
				this.operation.Completed += this.OnCompleted;
				this.operation.Progress += this.OnProgress;
			}
		}
	}
}

