﻿namespace CDays14StoreDemoApp
{
	using System.Collections.Generic;
	using System.Runtime.InteropServices;

	using Windows.ApplicationModel.Store;
	using Windows.UI.Popups;
#if !DEBUG  
		using StoreApp = Windows.ApplicationModel.Store.CurrentApp;
#else
	using StoreApp = Windows.ApplicationModel.Store.CurrentAppSimulator;
#endif

	using System;
	using Windows.Storage;
	using Windows.UI.Xaml;
	using Windows.UI.Xaml.Controls;

	/// <summary>
	/// An empty page that can be used on its own or navigated to within a Frame.
	/// </summary>
	public sealed partial class MainPage : Page
	{
		public MainPage()
		{
			this.InitializeComponent();
#if DEBUG
			this.LoadFakeStoreData();
#endif
		}

		private async void LoadFakeStoreData()
		{
			StorageFile file = await StorageFile.GetFileFromApplicationUriAsync(new Uri("ms-appx:///WindowsStoreProxy.xml"));
			await StoreApp.ReloadSimulatorAsync(file);
		}

		private async void GetStoreInfo(object sender, RoutedEventArgs e)
		{
			//A network connection is required...
			if (!this.IsConnectionAvailable) return;


			DataListBox.Items.Add(string.Format("AppId: {0}", StoreApp.AppId));
			DataListBox.Items.Add(string.Format("Link: {0}", StoreApp.LinkUri));
			DataListBox.Items.Add(string.Format("IsActive: {0}", StoreApp.LicenseInformation.IsActive));
			DataListBox.Items.Add(string.Format("IsTrial: {0}", StoreApp.LicenseInformation.IsTrial));
			DataListBox.Items.Add(string.Format("ExpireDate: {0}", StoreApp.LicenseInformation.ExpirationDate));

			//Listing info
			ListingInformation appListings = await StoreApp.LoadListingInformationAsync();
			DataListBox.Items.Add(string.Format("Current Market: {0}", appListings.CurrentMarket));
			DataListBox.Items.Add(string.Format("Current Price: {0}", appListings.FormattedPrice));
			foreach (ProductListing prodListing in appListings.ProductListings.Values)
			{
				DataListBox.Items.Add(
					string.Format(
						"Product Name:{0} Type:{1} FormattedPrice:{2}",
						prodListing.Name,
						prodListing.ProductType,
						prodListing.FormattedPrice));
			}
		}

		private async void OnBuy(object sender, RoutedEventArgs e)
		{
			string receipt = null;
			string msg;
			if (!StoreApp.LicenseInformation.IsTrial)
			{
				msg = "No need to buy!";
			}
			else
			{
				try
				{
					// Prompt the user to purchase a license for the app
					receipt = await CurrentApp.RequestAppPurchaseAsync(true);
					msg = StoreApp.LicenseInformation.IsActive ? "App license purchased" : "App license purchase cancelled";
				}
				catch (Exception ex)
				{
					msg = ex.Message;
				}
			}

			await new MessageDialog(msg).ShowAsync();

		}

		public bool IsConnectionAvailable
		{
			get
			{
				return true;
			}
		}
	}
}
