﻿

namespace EnumPackages
{
	using System;
	using System.Collections.Generic;
	using System.Linq;
	using System.Security.Principal;
	using System.Windows;
	using Windows.ApplicationModel;
	using Windows.Devices.Input;
	using Windows.Management.Deployment;

	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		public MainWindow()
		{
			InitializeComponent();
			this.OnProcess(null, null);
			this.DetectTouch();
		}

		private void OnProcess(object sender, RoutedEventArgs e)
		{
			PackageManager packageManager = new PackageManager();

			try
			{
				IEnumerable<Package> packages = packageManager.FindPackages().Where(p => !p.IsFramework);

				int packageCount = 0;
				foreach (var package in packages)
				{
					this.DisplayPackageInfo(package);
					this.DisplayPackageUsers(packageManager, package);

					Console.WriteLine();
					packageCount += 1;
				}

				if (packageCount < 1)
				{
					Console.WriteLine("No packages were found.");
				}

			}
			catch (UnauthorizedAccessException)
			{
				MessageBox.Show("packageManager.FindPackages() failed because access was denied. This program must be run from an elevated command prompt.");
			}
			catch (Exception ex)
			{
				MessageBox.Show(ex.Message);
			}
		}

		public async void DetectTouch()
		{
			TouchCapabilities touchCapability = new TouchCapabilities();
			bool hasTouch = touchCapability.TouchPresent > 0;
			TouchTextBlock.Text = string.Format("Touch {0}", hasTouch ? "presente" : "Non presente");
		}

		private void DisplayPackageUsers(PackageManager packageManager, Package package)
		{
			IEnumerable<PackageUserInformation> packageUsers = packageManager.FindUsers(package.Id.FullName);
			foreach (var packageUser in packageUsers)
			{
				string userInfo = string.Format("{0} ", this.SidToAccountName(packageUser.UserSecurityId));
				this.lb.Items.Add(userInfo);
			}

			this.lb.Items.Add("");
		}

		private string SidToAccountName(string sidString)
		{
			SecurityIdentifier sid = new SecurityIdentifier(sidString);
			try
			{
				NTAccount account = (NTAccount)sid.Translate(typeof(NTAccount));
				return account.ToString();
			}
			catch (IdentityNotMappedException)
			{
				return sidString;
			}
		}

		private void DisplayPackageInfo(Package package)
		{
			string path = null;
			try
			{
				path = package.InstalledLocation.Path;
			}
			catch (Exception)
			{
			}

			string info = string.Format(
				"{0}-{1}-{2}-{3}",
				package.Id.Name,
				package.Id.FullName,
				package.Id.Publisher,
				path);

			this.lb.Items.Add(info);
		}

	}
}
