﻿using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace NetworkInformations
{
	using System;
	using System.ServiceModel.Security;

	using Windows.Networking.BackgroundTransfer;
	using Windows.Networking.Connectivity;
	using Windows.Storage;
	using Windows.Storage.Streams;
	using Windows.Web.Http;
	using Windows.Web.Http.Filters;

	/// <summary>
	/// An empty page that can be used on its own or navigated to within a Frame.
	/// </summary>
	public sealed partial class MainPage : Page
	{
		public MainPage()
		{
			this.InitializeComponent();
		}

		private void GetNetworkInfo(object sender, RoutedEventArgs e)
		{
			//Connectivity level
			ConnectionProfile cp = NetworkInformation.GetInternetConnectionProfile();
			DataListBox.Items.Add("Connectivity Level: " + cp.GetNetworkConnectivityLevel());

			//Connections costs
			ConnectionCost connCost = cp.GetConnectionCost();
			DataListBox.Items.Add("Cost type: " + connCost.NetworkCostType);
			DataListBox.Items.Add("Roaming: " + connCost.Roaming);
			DataListBox.Items.Add("Is over limit: " + connCost.OverDataLimit);
			DataListBox.Items.Add("Is near limit: " + connCost.ApproachingDataLimit);

			//Monitor network status changes
			NetworkInformation.NetworkStatusChanged += this.OnNetworkChanged;
		}

		private void OnNetworkChanged(object sender)
		{
			//Status has changed...
		}

		private async void OnHttpClient(object sender, RoutedEventArgs e)
		{
			//System.Net.Http.HttpClient

			using (HttpClient client = new HttpClient())
			{
				string rawHtml = await client.GetStringAsync(new Uri("http://www.communitydays.it/"));
				DataListBox.Items.Clear();
				DataListBox.Items.Add(rawHtml.Substring(0, 400));
			}
		}

		private async void OnHttpSendRequest(object sender, RoutedEventArgs e)
		{
			this.OnContentPrefetcher();
			//return;

			using (HttpBaseProtocolFilter filter = new HttpBaseProtocolFilter())
			{
				//Read cache control
				filter.CacheControl.ReadBehavior = HttpCacheReadBehavior.MostRecent;

				using (HttpClient client = new HttpClient())
				{
					HttpRequestMessage request = new HttpRequestMessage(HttpMethod.Get, new Uri("http://www.repubblica.it/"));
					HttpResponseMessage response = await client.SendRequestAsync(request);

					DataListBox.Items.Clear();
					if (response.IsSuccessStatusCode)
					{
						string rawHtml = await response.Content.ReadAsStringAsync();
						DataListBox.Items.Add("Cache: " + ApplicationData.Current.LocalFolder.Path + @"\AC\INetCache");
						DataListBox.Items.Add(rawHtml.Substring(0, 300));
						DataListBox.Items.Add("Data taken from: " + response.Source);
					}
					else
					{
						DataListBox.Items.Add("Error");
					}
				}
			}
		}

		private async void OnContentPrefetcher()
		{
			string uri = "http://www.communitydays.it/GUI/logo_small.png";

			ContentPrefetcher.ContentUris.Add(new Uri(uri));
			DateTimeOffset? off = ContentPrefetcher.LastSuccessfulPrefetchTime;

			using (HttpClient client = new HttpClient())
			{
				HttpRequestMessage request = new HttpRequestMessage(HttpMethod.Get, new Uri(uri));
				HttpResponseMessage response = await client.SendRequestAsync(request);

				DataListBox.Items.Clear();
				if (response.IsSuccessStatusCode)
				{
					string rawHtml = await response.Content.ReadAsStringAsync();
					DataListBox.Items.Add(rawHtml.Substring(0, 300));
					DataListBox.Items.Add("Data taken from: " + response.Source);
				}
				else
				{
					DataListBox.Items.Add("Error");
				}
			}



		}
	}
}
