﻿using System;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=234238

namespace PackageData
{
	using System.Diagnostics;

	using Windows.Storage;
	using Windows.Storage.AccessCache;
	using Windows.Storage.Pickers;


	/// <summary>
	/// An empty page that can be used on its own or navigated to within a Frame.
	/// </summary>
	public sealed partial class MainPage : Page
	{
		private StorageFolder selectedFolder;


		public MainPage()
		{
			this.InitializeComponent();
		}

		private void OnSaveSetting(object sender, RoutedEventArgs e)
		{
			ApplicationDataContainer settingsContainer = ApplicationData.Current.LocalSettings;
			//Crea UserSetting area
			var container = settingsContainer.CreateContainer("UserSettings", ApplicationDataCreateDisposition.Always);
			container.Values["UserSetting1"] = "value1";
			container.Values["UserSetting2"] = "value2";
			//Crea settings atomici (max 64k)
			container.Values["UserAtomicSettings"] = new ApplicationDataCompositeValue()
			                                         {
				                                         { "UserId", "42" },
				                                         { "SavedAt", DateTime.Now.Ticks }
			                                         };
		}

		private async void OnLoadSetting(object sender, RoutedEventArgs e)
		{
			//Cancella tutti i dati salvati localmente
			//await ApplicationData.Current.ClearAsync(ApplicationDataLocality.Local);

			ApplicationDataContainer settingsContainer = ApplicationData.Current.LocalSettings;

			//Registra evento DataChanged, generato quando il pc sincronizza i dati
			ApplicationData.Current.DataChanged += this.OnDataChanged;


			//Get UserSetting area
			var container = settingsContainer.Containers["UserSettings"];
			string v1 = container.Values["UserSetting1"].ToString();
			string v2 = container.Values["UserSetting2"].ToString();



			ApplicationDataCompositeValue atomicSettings = (ApplicationDataCompositeValue)container.Values["UserAtomicSettings"];
			//Read atomic settings (max 64k)
			string userId = atomicSettings["UserId"].ToString();
			string savedAt = atomicSettings["SavedAt"].ToString();

			//Genera evento datachanged
			ApplicationData.Current.SignalDataChanged();
		}

		private void OnDataChanged(ApplicationData sender, object args)
		{
			Debug.WriteLine("DataChanged Triggered");
		}

		private async void OnSetVersion(object sender, RoutedEventArgs e)
		{
			const int RequiredVersion = 2;
			if (ApplicationData.Current.Version < RequiredVersion)
			{
				await ApplicationData.Current.SetVersionAsync(RequiredVersion, this.OnUpgradeSettings);

				//Impostato automaticamente alla nuova versione dopo SetVersionAsync
				uint newVersion = ApplicationData.Current.Version;
			}
		}

		private void OnUpgradeSettings(SetVersionRequest setVersionRequest)
		{
			switch (setVersionRequest.CurrentVersion)
			{
				case 0:
					if (setVersionRequest.DesiredVersion == 1)
					{
						ApplicationData.Current.RoamingSettings.Values["v1"] = "Upgraded";
					}
					if (setVersionRequest.DesiredVersion == 2)
					{
						ApplicationData.Current.RoamingSettings.Values["v2"] = "Upgraded";
					}
					break;
			}
		}

		private async void OnFilePicker(object sender, RoutedEventArgs e)
		{
			//StorageApplicationPermissions.FutureAccessList.Clear();
			bool saved = StorageApplicationPermissions.FutureAccessList.ContainsItem("FolderId");
			if (saved)
			{
				this.selectedFolder = await StorageApplicationPermissions.FutureAccessList.GetFolderAsync("FolderId");
			}
			else
			{
				var fop = new FolderPicker
							 {
								 FileTypeFilter = { "*" },
								 SuggestedStartLocation = PickerLocationId.VideosLibrary,
								 SettingsIdentifier = "fp1"
							 };

				this.selectedFolder = await fop.PickSingleFolderAsync();
				if (this.selectedFolder == null) return; // User canceled the picker

				//Add the folder to Future access list for safe further access
				StorageApplicationPermissions.FutureAccessList.AddOrReplace("FolderId", this.selectedFolder, "OptionalMetadataData");
			}

			//Do stuff with folder...
		}
	}
}
